=========
Changelog
=========

Unreleased
==========

-

Version 0.2
===========

- Update readme
- Switch to pyscaffold 3

Version 0.1
===========

- Initial version with support for Global EASE2 grids.
- The ad hoc calculation of some grids will not work out of the box and the
  map_scale will have to be given manually. The reason for this is that the
  official NASA grids use manual tweaks to define their grids.
